@@ -1108,13 +1108,12 @@ class TestExternalTaskSensorV3:
                 allowed_states=["success"],
             )
 
-        self.context["ti"].get_ti_count.return_value = 1
+        self.context["ti"].get_task_states.return_value = {"run_id": {"test_group.task_id": State.SUCCESS}}
         op.execute(context=self.context)
 
-        self.context["ti"].get_ti_count.assert_called_once_with(
+        self.context["ti"].get_task_states.assert_called_once_with(
             dag_id="test_dag_parent",
             logical_dates=[DEFAULT_DATE],
-            states=["success"],
             task_group_id="test_group",
         )
 
@@ -1226,15 +1225,14 @@ class TestExternalTaskSensorV3:
                 failed_states=[State.FAILED],
             )
 
-        self.context["ti"].get_ti_count.return_value = 1
+        self.context["ti"].get_task_states.return_value = {"run_id": {"test_group.task_id": State.FAILED}}
 
         with pytest.raises(AirflowException):
             op.execute(context=self.context)
 
-        self.context["ti"].get_ti_count.assert_called_once_with(
+        self.context["ti"].get_task_states.assert_called_once_with(
             dag_id="test_dag_parent",
             logical_dates=[DEFAULT_DATE],
-            states=[State.FAILED],
             task_group_id="test_group",
         )
 
@@ -1506,7 +1504,6 @@ def run_tasks(
                 run_after=logical_date,
                 run_type=DagRunType.MANUAL,
                 triggered_by=DagRunTriggeredByType.TEST,
-                dag_version=None,
                 state=DagRunState.RUNNING,
                 start_date=logical_date,
                 session=session,
